Documentation
¶
Index ¶
Constants ¶
const ( CRDGroup string = telemetry.GroupName CRDGroupVersion string = "v1" CRDContivTelemetryReportPlural string = "telemetryreports" )
CRD Constants
Variables ¶
var ( // SchemeGroupVersion defines the group version SchemeGroupVersion = schema.GroupVersion{Group: telemetry.GroupName, Version: "v1"} // SchemeBuilder is the schema builder for the CRD API SchemeBuilder = runtime.NewSchemeBuilder(addKnownTypes) // AddToScheme is... AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
func Resource ¶
func Resource(resource string) schema.GroupResource
Resource takes an unqualified resource and returns a Group qualified GroupResource
Types ¶
type TelemetryReport ¶
type TelemetryReport struct {
// TypeMeta is the metadata for the resource, like kind and apiversion
metav1.TypeMeta `json:",inline"`
// ObjectMeta contains the metadata for the particular object
metav1.ObjectMeta `json:"metadata,omitempty"`
// Spec is the custom resource spec
Spec TelemetryReportSpec `json:"spec,omitempty"`
Status TelemetryReportStatus `json:"status,omitempty"`
}
TelemetryReport describes contiv telemetry custom resource +genclient +k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object
func (*TelemetryReport) DeepCopy ¶
func (in *TelemetryReport) DeepCopy() *TelemetryReport
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TelemetryReport.
func (*TelemetryReport) DeepCopyInto ¶
func (in *TelemetryReport) DeepCopyInto(out *TelemetryReport)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*TelemetryReport) DeepCopyObject ¶
func (in *TelemetryReport) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type TelemetryReportList ¶
type TelemetryReportList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata"`
Items []TelemetryReport `json:"items"`
}
TelemetryReportList is a list of ContivTelemetryReport resource +k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object
func (*TelemetryReportList) DeepCopy ¶
func (in *TelemetryReportList) DeepCopy() *TelemetryReportList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TelemetryReportList.
func (*TelemetryReportList) DeepCopyInto ¶
func (in *TelemetryReportList) DeepCopyInto(out *TelemetryReportList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*TelemetryReportList) DeepCopyObject ¶
func (in *TelemetryReportList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type TelemetryReportSpec ¶
type TelemetryReportSpec struct {
ReportPollingPeriodSeconds uint32 `json:"report_polling_period_seconds"`
}
TelemetryReportSpec is the spec for the contiv telemetry resource
func (*TelemetryReportSpec) DeepCopy ¶
func (in *TelemetryReportSpec) DeepCopy() *TelemetryReportSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TelemetryReportSpec.
func (*TelemetryReportSpec) DeepCopyInto ¶
func (in *TelemetryReportSpec) DeepCopyInto(out *TelemetryReportSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type TelemetryReportStatus ¶
type TelemetryReportStatus struct {
UpdatedAt string `json:"updatedAt"`
Nodes []telemetrymodel.NodeInfo `json:"nodes"`
Reports telemetrymodel.Reports `json:"reports"`
}
TelemetryReportStatus is the state for the contiv telemetry report
func (*TelemetryReportStatus) DeepCopy ¶
func (in *TelemetryReportStatus) DeepCopy() *TelemetryReportStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TelemetryReportStatus.
func (*TelemetryReportStatus) DeepCopyInto ¶
func (in *TelemetryReportStatus) DeepCopyInto(out *TelemetryReportStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.