Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
- type ContivppV1Client
- func (c *ContivppV1Client) CustomConfigurations(namespace string) CustomConfigurationInterface
- func (c *ContivppV1Client) CustomNetworks(namespace string) CustomNetworkInterface
- func (c *ContivppV1Client) ExternalInterfaces(namespace string) ExternalInterfaceInterface
- func (c *ContivppV1Client) RESTClient() rest.Interface
- func (c *ContivppV1Client) ServiceFunctionChains(namespace string) ServiceFunctionChainInterface
- type ContivppV1Interface
- type CustomConfigurationExpansion
- type CustomConfigurationInterface
- type CustomConfigurationsGetter
- type CustomNetworkExpansion
- type CustomNetworkInterface
- type CustomNetworksGetter
- type ExternalInterfaceExpansion
- type ExternalInterfaceInterface
- type ExternalInterfacesGetter
- type ServiceFunctionChainExpansion
- type ServiceFunctionChainInterface
- type ServiceFunctionChainsGetter
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ContivppV1Client ¶
type ContivppV1Client struct {
// contains filtered or unexported fields
}
ContivppV1Client is used to interact with features provided by the contivpp.io group.
func New ¶
func New(c rest.Interface) *ContivppV1Client
New creates a new ContivppV1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*ContivppV1Client, error)
NewForConfig creates a new ContivppV1Client for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *ContivppV1Client
NewForConfigOrDie creates a new ContivppV1Client for the given config and panics if there is an error in the config.
func (*ContivppV1Client) CustomConfigurations ¶
func (c *ContivppV1Client) CustomConfigurations(namespace string) CustomConfigurationInterface
func (*ContivppV1Client) CustomNetworks ¶
func (c *ContivppV1Client) CustomNetworks(namespace string) CustomNetworkInterface
func (*ContivppV1Client) ExternalInterfaces ¶
func (c *ContivppV1Client) ExternalInterfaces(namespace string) ExternalInterfaceInterface
func (*ContivppV1Client) RESTClient ¶
func (c *ContivppV1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
func (*ContivppV1Client) ServiceFunctionChains ¶
func (c *ContivppV1Client) ServiceFunctionChains(namespace string) ServiceFunctionChainInterface
type ContivppV1Interface ¶
type ContivppV1Interface interface {
RESTClient() rest.Interface
CustomConfigurationsGetter
CustomNetworksGetter
ExternalInterfacesGetter
ServiceFunctionChainsGetter
}
type CustomConfigurationExpansion ¶
type CustomConfigurationExpansion interface{}
type CustomConfigurationInterface ¶
type CustomConfigurationInterface interface {
Create(*v1.CustomConfiguration) (*v1.CustomConfiguration, error)
Update(*v1.CustomConfiguration) (*v1.CustomConfiguration, error)
Delete(name string, options *metav1.DeleteOptions) error
DeleteCollection(options *metav1.DeleteOptions, listOptions metav1.ListOptions) error
Get(name string, options metav1.GetOptions) (*v1.CustomConfiguration, error)
List(opts metav1.ListOptions) (*v1.CustomConfigurationList, error)
Watch(opts metav1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1.CustomConfiguration, err error)
CustomConfigurationExpansion
}
CustomConfigurationInterface has methods to work with CustomConfiguration resources.
type CustomConfigurationsGetter ¶
type CustomConfigurationsGetter interface {
CustomConfigurations(namespace string) CustomConfigurationInterface
}
CustomConfigurationsGetter has a method to return a CustomConfigurationInterface. A group's client should implement this interface.
type CustomNetworkExpansion ¶
type CustomNetworkExpansion interface{}
type CustomNetworkInterface ¶
type CustomNetworkInterface interface {
Create(*v1.CustomNetwork) (*v1.CustomNetwork, error)
Update(*v1.CustomNetwork) (*v1.CustomNetwork, error)
Delete(name string, options *metav1.DeleteOptions) error
DeleteCollection(options *metav1.DeleteOptions, listOptions metav1.ListOptions) error
Get(name string, options metav1.GetOptions) (*v1.CustomNetwork, error)
List(opts metav1.ListOptions) (*v1.CustomNetworkList, error)
Watch(opts metav1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1.CustomNetwork, err error)
CustomNetworkExpansion
}
CustomNetworkInterface has methods to work with CustomNetwork resources.
type CustomNetworksGetter ¶
type CustomNetworksGetter interface {
CustomNetworks(namespace string) CustomNetworkInterface
}
CustomNetworksGetter has a method to return a CustomNetworkInterface. A group's client should implement this interface.
type ExternalInterfaceExpansion ¶
type ExternalInterfaceExpansion interface{}
type ExternalInterfaceInterface ¶
type ExternalInterfaceInterface interface {
Create(*v1.ExternalInterface) (*v1.ExternalInterface, error)
Update(*v1.ExternalInterface) (*v1.ExternalInterface, error)
Delete(name string, options *metav1.DeleteOptions) error
DeleteCollection(options *metav1.DeleteOptions, listOptions metav1.ListOptions) error
Get(name string, options metav1.GetOptions) (*v1.ExternalInterface, error)
List(opts metav1.ListOptions) (*v1.ExternalInterfaceList, error)
Watch(opts metav1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1.ExternalInterface, err error)
ExternalInterfaceExpansion
}
ExternalInterfaceInterface has methods to work with ExternalInterface resources.
type ExternalInterfacesGetter ¶
type ExternalInterfacesGetter interface {
ExternalInterfaces(namespace string) ExternalInterfaceInterface
}
ExternalInterfacesGetter has a method to return a ExternalInterfaceInterface. A group's client should implement this interface.
type ServiceFunctionChainExpansion ¶
type ServiceFunctionChainExpansion interface{}
type ServiceFunctionChainInterface ¶
type ServiceFunctionChainInterface interface {
Create(*v1.ServiceFunctionChain) (*v1.ServiceFunctionChain, error)
Update(*v1.ServiceFunctionChain) (*v1.ServiceFunctionChain, error)
Delete(name string, options *metav1.DeleteOptions) error
DeleteCollection(options *metav1.DeleteOptions, listOptions metav1.ListOptions) error
Get(name string, options metav1.GetOptions) (*v1.ServiceFunctionChain, error)
List(opts metav1.ListOptions) (*v1.ServiceFunctionChainList, error)
Watch(opts metav1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1.ServiceFunctionChain, err error)
ServiceFunctionChainExpansion
}
ServiceFunctionChainInterface has methods to work with ServiceFunctionChain resources.
type ServiceFunctionChainsGetter ¶
type ServiceFunctionChainsGetter interface {
ServiceFunctionChains(namespace string) ServiceFunctionChainInterface
}
ServiceFunctionChainsGetter has a method to return a ServiceFunctionChainInterface. A group's client should implement this interface.