Documentation
¶
Index ¶
- func Key(name string, namespace string) string
- func KeyPrefix() string
- type Sfc
- func (*Sfc) Descriptor() ([]byte, []int)
- func (m *Sfc) GetNode() string
- func (m *Sfc) GetPod() string
- func (*Sfc) ProtoMessage()
- func (m *Sfc) Reset()
- func (m *Sfc) String() string
- func (m *Sfc) XXX_DiscardUnknown()
- func (m *Sfc) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *Sfc) XXX_Merge(src proto.Message)
- func (m *Sfc) XXX_Size() int
- func (m *Sfc) XXX_Unmarshal(b []byte) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Sfc ¶
type Sfc struct {
// Name of the pod unique within the namespace.
// Cannot be updated.
Pod string `protobuf:"bytes,1,opt,name=pod,proto3" json:"pod,omitempty"`
// Node the pod is deployed into into.
// Can be updated
Node string `protobuf:"bytes,2,opt,name=node,proto3" json:"node,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
Pod is a collection of containers that can run on a host. This resource is created by clients and scheduled onto hosts.
func (*Sfc) Descriptor ¶
func (*Sfc) ProtoMessage ¶
func (*Sfc) ProtoMessage()
func (*Sfc) XXX_DiscardUnknown ¶
func (m *Sfc) XXX_DiscardUnknown()
func (*Sfc) XXX_Unmarshal ¶
Click to show internal directories.
Click to hide internal directories.